==> estateplat-common-1.1.0-20160822.104948-162-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTdcbnydsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 土地承包经营权、农用地使用权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_tdcbnydsyq")
public class BdcTdcbnydsyq extends QllxParent {
    /* @Id
  private String qlid;//权利Id
  private String bdcdyid;//不动产单元Id*/
    private Date syksqx;//使用开始期限
    private Date syjsqx;//使用结束期限
    private String syttlx;//水域滩涂类型
    private String yzyfs;//养殖业方式
    private String cyzl;//草原质量
    private Integer syzcl;//适宜载畜量
    private Double syqmj;//承包（使用权）面积（亩）
    private String tdsyqxz;//土地所有权性质
    private String ywh;//业务号
    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记

    private Integer qszt;//权属状态
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间

    private String fbfmc;//发包方名称
    private String qdcbfs;//取得承包方式

    public String getQdcbfs() {
        return qdcbfs;
    }

    public void setQdcbfs(String qdcbfs) {
        this.qdcbfs = qdcbfs;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public Date getSyksqx() {
        return syksqx;
    }

    public void setSyksqx(Date syksqx) {
        this.syksqx = syksqx;
    }

    public Date getSyjsqx() {
        return syjsqx;
    }

    public void setSyjsqx(Date syjsqx) {
        this.syjsqx = syjsqx;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

}

==> estateplat-common-1.2.1-20170713.060811-58-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTdcbnydsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 土地承包经营权、农用地使用权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_tdcbnydsyq")
public class BdcTdcbnydsyq extends QllxParent {
    /* @Id
  private String qlid;//权利Id
  private String bdcdyid;//不动产单元Id*/
    private Date syksqx;//使用开始期限
    private Date syjsqx;//使用结束期限
    private String syttlx;//水域滩涂类型
    private String yzyfs;//养殖业方式
    private String cyzl;//草原质量
    private Integer syzcl;//适宜载畜量
    private Double syqmj;//承包（使用权）面积（亩）
    private String tdsyqxz;//土地所有权性质
    private String ywh;//业务号
    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记

    private Integer qszt;//权属状态
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间

    private String fbfmc;//发包方名称
    private String qdcbfs;//取得承包方式
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getQdcbfs() {
        return qdcbfs;
    }

    public void setQdcbfs(String qdcbfs) {
        this.qdcbfs = qdcbfs;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public Date getSyksqx() {
        return syksqx;
    }

    public void setSyksqx(Date syksqx) {
        this.syksqx = syksqx;
    }

    public Date getSyjsqx() {
        return syjsqx;
    }

    public void setSyjsqx(Date syjsqx) {
        this.syjsqx = syjsqx;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

}
